@@ -85,8 +85,8 @@ info = {
         "قظ"
     ],
     "pm": [
-        "بعدازظهر",
-        "بظ"
+        "بظ",
+        "بعدازظهر"
     ],
     "year": [
         "سال"
@@ -111,103 +111,103 @@ info = {
         "دوم"
     ],
     "relative-type": {
-        "1 year ago": [
-            "سال گذشته"
-        ],
-        "0 year ago": [
-            "امسال"
-        ],
-        "in 1 year": [
-            "سال آینده"
-        ],
-        "1 month ago": [
-            "ماه گذشته",
-            "ماه پیش"
-        ],
-        "0 month ago": [
-            "این ماه"
-        ],
-        "in 1 month": [
-            "ماه آینده"
-        ],
-        "1 week ago": [
-            "هفتهٔ گذشته"
-        ],
-        "0 week ago": [
-            "این هفته"
-        ],
-        "in 1 week": [
-            "هفتهٔ آینده"
-        ],
-        "1 day ago": [
-            "دیروز"
-        ],
         "0 day ago": [
             "امروز"
         ],
-        "in 1 day": [
-            "فردا"
-        ],
         "0 hour ago": [
             "همین ساعت"
         ],
         "0 minute ago": [
             "همین دقیقه"
         ],
+        "0 month ago": [
+            "این ماه"
+        ],
         "0 second ago": [
             "اکنون"
+        ],
+        "0 week ago": [
+            "این هفته"
+        ],
+        "0 year ago": [
+            "امسال"
+        ],
+        "1 day ago": [
+            "دیروز"
+        ],
+        "1 month ago": [
+            "ماه پیش",
+            "ماه گذشته"
+        ],
+        "1 week ago": [
+            "هفتهٔ گذشته"
+        ],
+        "1 year ago": [
+            "سال گذشته"
+        ],
+        "in 1 day": [
+            "فردا"
+        ],
+        "in 1 month": [
+            "ماه آینده"
+        ],
+        "in 1 week": [
+            "هفتهٔ آینده"
+        ],
+        "in 1 year": [
+            "سال آینده"
         ]
     },
     "relative-type-regex": {
-        "in \\1 year": [
-            "(\\d+) سال بعد"
-        ],
-        "\\1 year ago": [
-            "(\\d+) سال پیش"
-        ],
-        "in \\1 month": [
-            "(\\d+) ماه بعد"
-        ],
-        "\\1 month ago": [
-            "(\\d+) ماه پیش"
-        ],
-        "in \\1 week": [
-            "(\\d+) هفته بعد"
-        ],
-        "\\1 week ago": [
-            "(\\d+) هفته پیش"
-        ],
-        "in \\1 day": [
-            "(\\d+) روز بعد"
-        ],
         "\\1 day ago": [
             "(\\d+) روز پیش"
         ],
-        "in \\1 hour": [
-            "(\\d+) ساعت بعد"
-        ],
         "\\1 hour ago": [
             "(\\d+) ساعت پیش"
         ],
+        "\\1 minute ago": [
+            "(\\d+) دقیقه پیش"
+        ],
+        "\\1 month ago": [
+            "(\\d+) ماه پیش"
+        ],
+        "\\1 second ago": [
+            "(\\d+) ثانیه پیش"
+        ],
+        "\\1 week ago": [
+            "(\\d+) هفته پیش"
+        ],
+        "\\1 year ago": [
+            "(\\d+) سال پیش"
+        ],
+        "in \\1 day": [
+            "(\\d+) روز بعد"
+        ],
+        "in \\1 hour": [
+            "(\\d+) ساعت بعد"
+        ],
         "in \\1 minute": [
             "(\\d+) دقیقه بعد"
         ],
-        "\\1 minute ago": [
-            "(\\d+) دقیقه پیش"
+        "in \\1 month": [
+            "(\\d+) ماه بعد"
         ],
         "in \\1 second": [
             "(\\d+) ثانیه بعد"
         ],
-        "\\1 second ago": [
-            "(\\d+) ثانیه پیش"
+        "in \\1 week": [
+            "(\\d+) هفته بعد"
+        ],
+        "in \\1 year": [
+            "(\\d+) سال بعد"
         ]
     },
     "locale_specific": {
         "fa-AF": {
             "name": "fa-AF",
             "january": [
-                "جنوری",
-                "جنو"
+                "جنو",
+                "جنوری"
             ],
             "february": [
                 "فبروری"
@@ -241,8 +241,8 @@ info = {
                 "نومبر"
             ],
             "december": [
-                "دسمبر",
-                "دسم"
+                "دسم",
+                "دسمبر"
             ]
         }
     },
@@ -255,16 +255,16 @@ info = {
     ],
     "skip": [
         " ",
-        ".",
-        ",",
-        ";",
-        "-",
-        "/",
         "'",
-        "|",
+        ",",
+        "-",
+        ".",
+        "/",
+        ";",
         "@",
         "[",
         "]",
+        "|",
         "，"
     ]
 }
