@@ -1,88 +1,87 @@
-# -*- coding: utf-8 -*-
 info = {
     "name": "zh",
     "date_order": "YMD",
     "january": [
-        "一月",
-        "1月"
+        "1月",
+        "一月"
     ],
     "february": [
-        "二月",
-        "2月"
+        "2月",
+        "二月"
     ],
     "march": [
-        "三月",
-        "3月"
+        "3月",
+        "三月"
     ],
     "april": [
-        "四月",
-        "4月"
+        "4月",
+        "四月"
     ],
     "may": [
-        "五月",
-        "5月"
+        "5月",
+        "五月"
     ],
     "june": [
-        "六月",
-        "6月"
+        "6月",
+        "六月"
     ],
     "july": [
-        "七月",
-        "7月"
+        "7月",
+        "七月"
     ],
     "august": [
-        "八月",
-        "8月"
+        "8月",
+        "八月"
     ],
     "september": [
-        "九月",
-        "9月"
+        "9月",
+        "九月"
     ],
     "october": [
-        "十月",
-        "10月"
+        "10月",
+        "十月"
     ],
     "november": [
-        "十一月",
-        "11月"
+        "11月",
+        "十一月"
     ],
     "december": [
-        "十二月",
-        "12月"
+        "12月",
+        "十二月"
     ],
     "monday": [
-        "星期一",
         "周一",
+        "星期一",
         "礼拜一"
     ],
     "tuesday": [
-        "星期二",
         "周二",
+        "星期二",
         "礼拜二"
     ],
     "wednesday": [
-        "星期三",
         "周三",
+        "星期三",
         "礼拜三"
     ],
     "thursday": [
-        "星期四",
         "周四",
+        "星期四",
         "礼拜四"
     ],
     "friday": [
-        "星期五",
         "周五",
+        "星期五",
         "礼拜五"
     ],
     "saturday": [
-        "星期六",
         "周六",
+        "星期六",
         "礼拜六"
     ],
     "sunday": [
-        "星期日",
         "周日",
+        "星期日",
         "星期天",
         "礼拜日",
         "礼拜天"
@@ -113,106 +112,107 @@ info = {
         "小时"
     ],
     "minute": [
-        "分钟",
-        "分"
+        "分",
+        "分钟"
     ],
     "second": [
         "秒"
     ],
     "relative-type": {
-        "1 year ago": [
-            "去年"
-        ],
-        "0 year ago": [
-            "今年"
-        ],
-        "in 1 year": [
-            "明年"
-        ],
-        "1 month ago": [
-            "上个月"
-        ],
-        "0 month ago": [
-            "本月"
-        ],
-        "in 1 month": [
-            "下个月"
-        ],
-        "1 week ago": [
-            "上周"
-        ],
-        "0 week ago": [
-            "本周"
-        ],
-        "in 1 week": [
-            "下周"
-        ],
-        "1 day ago": [
-            "昨天"
-        ],
         "0 day ago": [
             "今天"
         ],
-        "in 1 day": [
-            "明天"
-        ],
         "0 hour ago": [
             "这一时间 / 此时"
         ],
         "0 minute ago": [
             "此刻"
         ],
+        "0 month ago": [
+            "本月"
+        ],
         "0 second ago": [
-            "现在"
+            "现在",
+            "刚刚"
+        ],
+        "0 week ago": [
+            "本周"
+        ],
+        "0 year ago": [
+            "今年"
+        ],
+        "1 day ago": [
+            "昨天"
+        ],
+        "1 month ago": [
+            "上个月"
+        ],
+        "1 week ago": [
+            "上周"
+        ],
+        "1 year ago": [
+            "去年"
+        ],
+        "in 1 day": [
+            "明天"
+        ],
+        "in 1 month": [
+            "下个月"
+        ],
+        "in 1 week": [
+            "下周"
+        ],
+        "in 1 year": [
+            "明年"
         ],
         "2 day ago": [
             "前天"
         ]
     },
     "relative-type-regex": {
-        "in \\1 year": [
-            "(\\d+)年后"
-        ],
-        "\\1 year ago": [
-            "(\\d+)年前"
-        ],
-        "in \\1 month": [
-            "(\\d+)个月后"
-        ],
-        "\\1 month ago": [
-            "(\\d+)个月前"
-        ],
-        "in \\1 week": [
-            "(\\d+)周后"
-        ],
-        "\\1 week ago": [
-            "(\\d+)周前"
-        ],
-        "in \\1 day": [
-            "(\\d+)天后"
-        ],
         "\\1 day ago": [
             "(\\d+)天前"
         ],
-        "in \\1 hour": [
-            "(\\d+)小时后"
-        ],
         "\\1 hour ago": [
             "(\\d+)小时前"
         ],
-        "in \\1 minute": [
-            "(\\d+)分钟后"
-        ],
         "\\1 minute ago": [
             "(\\d+)分钟前"
         ],
-        "in \\1 second": [
-            "(\\d+)秒钟后",
-            "(\\d+)秒后"
+        "\\1 month ago": [
+            "(\\d+)个月前"
         ],
         "\\1 second ago": [
-            "(\\d+)秒钟前",
-            "(\\d+)秒前"
+            "(\\d+)秒前",
+            "(\\d+)秒钟前"
+        ],
+        "\\1 week ago": [
+            "(\\d+)周前"
+        ],
+        "\\1 year ago": [
+            "(\\d+)年前"
+        ],
+        "in \\1 day": [
+            "(\\d+)天后"
+        ],
+        "in \\1 hour": [
+            "(\\d+)小时后"
+        ],
+        "in \\1 minute": [
+            "(\\d+)分钟后"
+        ],
+        "in \\1 month": [
+            "(\\d+)个月后"
+        ],
+        "in \\1 second": [
+            "(\\d+)秒后",
+            "(\\d+)秒钟后"
+        ],
+        "in \\1 week": [
+            "(\\d+)周后"
+        ],
+        "in \\1 year": [
+            "(\\d+)年后"
         ]
     },
     "locale_specific": {},
@@ -221,16 +221,16 @@ info = {
     "skip": [
         "约",
         " ",
-        ".",
-        ",",
-        ";",
-        "-",
-        "/",
         "'",
-        "|",
+        ",",
+        "-",
+        ".",
+        "/",
+        ";",
         "@",
         "[",
         "]",
+        "|",
         "，"
     ],
     "ago": [
